=========================
Atomic Simulation Recipes
=========================


.. image:: https://img.shields.io/pypi/v/asr.svg
        :target: https://pypi.python.org/pypi/asr

.. image:: https://img.shields.io/travis/mortengjerding/asr.svg
        :target: https://travis-ci.org/mortengjerding/asr

.. image:: https://readthedocs.org/projects/asr/badge/?version=latest
        :target: https://asr.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/gitlab/mortengjerding/asr/shield.svg
     :target: https://pyup.io/repos/gitlab/mortengjerding/asr/
     :alt: Updates



ASE recipes for calculating material properties


* Free software: GNU General Public License v3
* Documentation: https://asr.readthedocs.io.
* Code: https://gitlab.com/mortengjerding/asr.git

Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://gitlab.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://gitlab.com/audreyr/cookiecutter-pypackage
